//[mahjong-utils](../../../../index.md)/[mahjongutils.hora](../../index.md)/[RegularHoraHandPattern](../index.md)/[Companion](index.md)/[build](build.md)

# build

[common]\
fun [build](build.md)(pattern: [RegularHandPattern](../../../mahjongutils.models.hand/-regular-hand-pattern/index.md), agari: [Tile](../../../mahjongutils.models/-tile/index.md), tsumo: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html), selfWind: [Wind](../../../mahjongutils.models/-wind/index.md)? = null, roundWind: [Wind](../../../mahjongutils.models/-wind/index.md)? = null): [Collection](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-collection/index.html)&lt;[RegularHoraHandPattern](../index.md)&gt;

构建标准形和牌手牌

#### Return

所有可能的和牌手牌

#### Parameters

common

| | |
|---|---|
| pattern | 手牌形 |
| agari | 和牌张 |
| tsumo | 是否自摸 |
| selfWind | 自风 |
| roundWind | 场风 |
